@@ -4,10 +4,10 @@ from fastapi import FastAPI
 from nonebot import get_driver
 from nonebot.drivers import ReverseDriver
 
-from .log import logger
+from . import plugin  # noqa: F401
 from .plugin_config import config
-from .process import BINARY_PATH, GoCQProcess, ProcessesManager, download_gocq
-from .web.routes import app
+from .process import BINARY_DIR, BINARY_PATH, ProcessesManager, download_gocq
+from .web import app
 
 driver = get_driver()
 
@@ -16,27 +16,31 @@ if isinstance(driver, ReverseDriver) and isinstance(driver.asgi, FastAPI):
 else:
     raise NotImplementedError("Support for FastAPI is only available.")
 
+ACCOUNTS_DATA = BINARY_DIR / "accounts.pkl"
+
 
 @driver.on_startup
 async def startup():
     if config.FORCE_DOWNLOAD or not BINARY_PATH.is_file():
         await download_gocq()
 
-    for account in config.ACCOUNTS:
-        logger.info(f"Starting GoCQ process for <e>{account.uin}</e>")
-        process = GoCQProcess(account)
-        await process.start()
+    ProcessesManager.load_config()
+    if ACCOUNTS_DATA.is_file():
+        await ProcessesManager.load_saved(ACCOUNTS_DATA, ignore_loaded=True)
 
-    return
-
-
-@driver.on_shutdown
-async def shutdown():
     await asyncio.gather(
-        *map(lambda process: process.stop(), ProcessesManager.all()),
+        *map(lambda process: process.start(), ProcessesManager.all()),
         return_exceptions=True,
     )
     return
 
 
-from . import plugin  # noqa: F401,E402
+@driver.on_shutdown
+async def shutdown():
+    await ProcessesManager.save(ACCOUNTS_DATA)
+
+    await asyncio.gather(
+        *map(lambda process: process.stop(), ProcessesManager.all()),
+        return_exceptions=True,
+    )
+    return
